colour_hdri.tonemapping.global_operators — Colour - HDRI 0.1.0 documentation

# Source code for colour_hdri.tonemapping.global_operators

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .operators import (
        tonemapping_operator_simple,
        tonemapping_operator_normalisation,
        tonemapping_operator_gamma,
        tonemapping_operator_logarithmic,
        tonemapping_operator_exponential,
        tonemapping_operator_logarithmic_mapping,
        tonemapping_operator_exponentiation_mapping,
        tonemapping_operator_Schlick1994,
        tonemapping_operator_Tumblin1999,
        tonemapping_operator_Reinhard2004,
        tonemapping_operator_filmic)

    __all__ = [
        'tonemapping_operator_simple',
        'tonemapping_operator_normalisation',
        'tonemapping_operator_gamma',
        'tonemapping_operator_logarithmic',
        'tonemapping_operator_exponential',
        'tonemapping_operator_logarithmic_mapping',
        'tonemapping_operator_exponentiation_mapping',
        'tonemapping_operator_Schlick1994',
        'tonemapping_operator_Tumblin1999',
        'tonemapping_operator_Reinhard2004',
        'tonemapping_operator_filmic']